@@ -20,18 +20,53 @@ class FeatureFlagConstants:
     CONDITIONS = "conditions"
     CLIENT_FILTERS = "client_filters"
     REQUIREMENT_TYPE = "requirement_type"
-    FILTER_NAME = "name"
+    DISPLAY_NAME = "display_name"
+    NAME = "name"
     FILTER_PARAMETERS = "parameters"
+    ALLOCATION = "allocation"
+    TELEMETRY = "telemetry"
+    VARIANTS = "variants"
+
+    # allocation properties
+    GROUP = "group"
+    USER = "user"
+    PERCENTILE = "percentile"
+    DEFAULT_WHEN_ENABLED = "default_when_enabled"
+    DEFAULT_WHEN_DISABLED = "default_when_disabled"
+    SEED = "seed"
+
+    # variant properties
+    VARIANT = "variant"
+    VARIANT_CONFIGURATION_VALUE = "configuration_value"
+    VARIANT_STATUS_OVERRIDE = "status_override"
+
+    # percentile properties
+    FROM = "from"
+    TO = "to"
+
+    # allocation user/group properties
+    USERS = "users"
+    GROUPS = "groups"
 
     # Requirement type options
-    REQUIREMENT_TYPE_ALL = "all"
-    REQUIREMENT_TYPE_ANY = "any"
+    REQUIREMENT_TYPE_ALL = "All"
+    REQUIREMENT_TYPE_ANY = "Any"
+
+    # Telemetry properties
+    METADATA = "metadata"
+
+    # feature flags key
+    FEATURE_FLAGS_KEY = "feature_flags"
 
 
 class KeyVaultConstants:
     KEYVAULT_CONTENT_TYPE = "application/vnd.microsoft.appconfig.keyvaultref+json;charset=utf-8"
 
 
+class AIConfigConstants:
+    AI_CHAT_COMPLETION_CONTENT_TYPE = "application/vnd.microsoft.appconfig.aichatcompletion+json;charset=utf-8"
+
+
 class AppServiceConstants:
     APPSVC_CONFIG_REFERENCE_PREFIX = "@Microsoft.AppConfiguration"
     APPSVC_KEYVAULT_PREFIX = "@Microsoft.KeyVault"
@@ -89,8 +124,10 @@ class ImportExportProfiles:
     DEFAULT = "appconfig/default"
 
 
-class SnapshotConstants:
-    API_VERSION = "2023-10-01"
+class SnapshotFilterFields:
+    KEY = "key"
+    LABEL = "label"
+    TAGS = "tags"
 
 
 class JsonDiff:
@@ -111,6 +148,7 @@ class CompareFields:
 CompareFieldsMap = {
     "appconfig": (CompareFields.CONTENT_TYPE, CompareFields.VALUE, CompareFields.TAGS),
     "appservice": (CompareFields.VALUE, CompareFields.TAGS),
+    "aks": (CompareFields.CONTENT_TYPE, CompareFields.VALUE, CompareFields.TAGS),
     "file": (CompareFields.CONTENT_TYPE, CompareFields.VALUE),
     "kvset": (CompareFields.CONTENT_TYPE, CompareFields.VALUE, CompareFields.TAGS),
     "restore": (CompareFields.VALUE, CompareFields.CONTENT_TYPE, CompareFields.LOCKED, CompareFields.TAGS)
@@ -120,3 +158,14 @@ CompareFieldsMap = {
 class ImportMode:
     ALL = "all"
     IGNORE_MATCH = "ignore-match"
+
+
+class ProvisioningStatus:
+    RUNNING = "Running"
+    SUCCEEDED = "Succeeded"
+    FAILED = "Failed"
+
+
+class ARMAuthenticationMode:
+    LOCAL = "local"
+    PASS_THROUGH = "pass-through"
