@@ -216,7 +216,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
     )
 
     mysql_version_upgrade_arg_type = CLIArgumentType(
-        arg_type=get_enum_type(['8']),
+        arg_type=get_enum_type(['8', '8.4']),
         options_list=['--version', '-v'],
         help='Server major version.'
     )
@@ -372,7 +372,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('public_access', arg_type=public_access_create_arg_type)
         c.argument('vnet', arg_type=vnet_arg_type)
         c.argument('vnet_address_prefix', arg_type=vnet_address_prefix_arg_type)
-        c.argument('storage_redundancy', arg_type=storage_redundancy_arg_type)
+        c.argument('storage_redundancy', arg_type=storage_redundancy_arg_type, default="LocalRedundancy")
         c.argument('subnet', arg_type=subnet_arg_type)
         c.argument('subnet_address_prefix', arg_type=subnet_address_prefix_arg_type)
         c.argument('private_dns_zone_arguments', private_dns_zone_arguments_arg_type)
@@ -479,6 +479,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('storage_gb', arg_type=storage_gb_arg_type)
         c.argument('standby_availability_zone', arg_type=standby_availability_zone_arg_type)
         c.argument('high_availability', arg_type=high_availability_arg_type)
+        c.argument('backup_interval', arg_type=backup_interval_arg_type)
         c.argument('byok_key', arg_type=key_arg_type)
         c.argument('byok_identity', arg_type=identity_arg_type)
         c.argument('auto_grow', arg_type=auto_grow_arg_type)
@@ -593,7 +594,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('sku_name', arg_type=sku_name_arg_type)
         c.argument('storage_gb', arg_type=storage_gb_arg_type)
         c.argument('iops', arg_type=iops_arg_type)
-        c.argument('storage_redundancy', arg_type=storage_redundancy_arg_type)
+        c.argument('storage_redundancy', arg_type=storage_redundancy_arg_type, default="LocalRedundancy")
         c.argument('faster_provisioning', arg_type=faster_provisioning_arg_type)
         c.argument('database_port', arg_type=database_port_arg_type)
         c.argument('backup_retention', arg_type=mysql_backup_retention_arg_type)
