@@ -5,9 +5,10 @@
 
 from azure.cli.testsdk import ScenarioTest, ResourceGroupPreparer
 from knack.util import CLIError
+from azure.core.exceptions import HttpResponseError
+from azure.cli.core.azclierror import InvalidArgumentValueError
 
 POOL_DEFAULT = "--service-level Premium --size 4"
-POOL_DEFAULT_TOO_SMALL = "--service-level 'Premium' --size 1"
 POOL_DEFAULT_STRING_SIZE = "--service-level 'Premium' --size a"
 LOCATION = "eastus2euap"
 
@@ -33,7 +34,7 @@ class AzureNetAppFilesPoolServiceScenarioTest(ScenarioTest):
         pool_list = self.cmd("netappfiles pool list --resource-group {rg} --account-name %s" % account_name).get_output_in_json()
         assert len(pool_list) == 1
 
-        self.cmd("az netappfiles pool delete --resource-group {rg} --account-name '%s' --pool-name '%s'" % (account_name, pool_name))
+        self.cmd("az netappfiles pool delete --resource-group {rg} --account-name '%s' --pool-name '%s' -y" % (account_name, pool_name))
         pool_list = self.cmd("netappfiles pool list --resource-group {rg} --account-name %s" % account_name).get_output_in_json()
         assert len(pool_list) == 0
 
@@ -44,18 +45,10 @@ class AzureNetAppFilesPoolServiceScenarioTest(ScenarioTest):
         assert pool['tags']['Tag2'] == 'Value2'
         assert pool['qosType'] == 'Auto'
 
-        self.cmd("az netappfiles pool delete --resource-group {rg} -a %s -p %s" % (account_name, pool_name))
+        self.cmd("az netappfiles pool delete --resource-group {rg} -a %s -p %s -y" % (account_name, pool_name))
         pool_list = self.cmd("netappfiles pool list --resource-group {rg} -a %s" % account_name).get_output_in_json()
         assert len(pool_list) == 0
 
-    @ResourceGroupPreparer(name_prefix='cli_netappfiles_test_pool_', additional_tags={'owner': 'cli_test'})
-    def test_create_pool_too_small(self):
-        account_name = self.create_random_name(prefix='cli-acc-', length=24)
-        pool_name = self.create_random_name(prefix='cli-pool-', length=24)
-
-        self.cmd("az netappfiles account create --resource-group {rg} --account-name '%s' -l %s" % (account_name, LOCATION)).get_output_in_json()
-        with self.assertRaises(CLIError):
-            self.cmd("az netappfiles pool create --resource-group {rg} --account-name %s --pool-name %s -l %s %s " % (account_name, pool_name, LOCATION, POOL_DEFAULT_TOO_SMALL)).get_output_in_json()
 
     @ResourceGroupPreparer(name_prefix='cli_netappfiles_test_pool_', additional_tags={'owner': 'cli_test'})
     def test_create_pool_string_size(self):
@@ -63,7 +56,7 @@ class AzureNetAppFilesPoolServiceScenarioTest(ScenarioTest):
         pool_name = self.create_random_name(prefix='cli-pool-', length=24)
 
         self.cmd("az netappfiles account create --resource-group {rg} --account-name '%s' -l %s" % (account_name, LOCATION)).get_output_in_json()
-        with self.assertRaises(CLIError):
+        with self.assertRaises(InvalidArgumentValueError):
             self.cmd("az netappfiles pool create --resource-group {rg} --account-name %s --pool-name %s -l %s %s " % (account_name, pool_name, LOCATION, POOL_DEFAULT_STRING_SIZE)).get_output_in_json()
 
     @ResourceGroupPreparer(name_prefix='cli_netappfiles_test_pool_', additional_tags={'owner': 'cli_test'})
@@ -79,7 +72,7 @@ class AzureNetAppFilesPoolServiceScenarioTest(ScenarioTest):
         assert len(pool_list) == 2
 
         for pool_name in pools:
-            self.cmd("az netappfiles pool delete -g {rg} -a %s -p %s" % (account_name, pool_name))
+            self.cmd("az netappfiles pool delete -g {rg} -a %s -p %s -y" % (account_name, pool_name))
         pool_list = self.cmd("netappfiles pool list --resource-group {rg} -a '%s'" % account_name).get_output_in_json()
         assert len(pool_list) == 0
 
