@@ -14,7 +14,7 @@ from azure.cli.testsdk.scenario_tests import AllowLargeResponse
 
 
 # This test example is from
-# https://docs.microsoft.com/en-us/azure/active-directory/develop/howto-add-app-roles-in-azure-ad-apps#example-user-app-role
+# https://learn.microsoft.com/en-us/azure/active-directory/develop/howto-add-app-roles-in-azure-ad-apps#example-user-app-role
 TEST_APP_ROLES = '''[
     {
         "allowedMemberTypes": [
@@ -40,7 +40,7 @@ TEST_APP_ROLES = '''[
 '''
 
 # This test example is from
-# https://docs.microsoft.com/en-us/azure/active-directory/develop/active-directory-optional-claims#configuring-optional-claims
+# https://learn.microsoft.com/en-us/azure/active-directory/develop/active-directory-optional-claims#configuring-optional-claims
 TEST_OPTIONAL_CLAIMS = '''{
     "idToken": [
         {
@@ -95,7 +95,7 @@ TEST_REQUIRED_RESOURCE_ACCESS = '''[
 '''
 
 # This test example is from
-# https://docs.microsoft.com/en-us/azure/active-directory/develop/workload-identity-federation-create-trust-github?tabs=microsoft-graph
+# https://learn.microsoft.com/en-us/azure/active-directory/develop/workload-identity-federation-create-trust-github?tabs=microsoft-graph
 TEST_FEDERATED_IDENTITY_CREDENTIAL = '''{
     "name": "Testing",
     "issuer": "https://token.actions.githubusercontent.com/",
@@ -208,7 +208,7 @@ class ApplicationScenarioTest(GraphScenarioTestBase):
         display_name = self.create_random_name(prefix='azure-cli-test', length=30)
 
         # identifierUris must be on verified domain
-        # https://docs.microsoft.com/en-us/azure/active-directory/develop/security-best-practices-for-app-registration#appid-uri-configuration
+        # https://learn.microsoft.com/en-us/azure/active-directory/develop/security-best-practices-for-app-registration#appid-uri-configuration
         self.kwargs.update({
             'display_name': display_name,
             'identifier_uri': f'api://{display_name}',
@@ -221,7 +221,8 @@ class ApplicationScenarioTest(GraphScenarioTestBase):
             'app_roles': TEST_APP_ROLES,
             'optional_claims': TEST_OPTIONAL_CLAIMS,
             'required_resource_accesses': TEST_REQUIRED_RESOURCE_ACCESS,
-            'service_management_reference': '96524024-75b0-497b-ab38-0381399a6a9d'
+            'service_management_reference': '96524024-75b0-497b-ab38-0381399a6a9d',
+            'requested_access_token_version': 2
         })
 
         # Create
@@ -231,6 +232,8 @@ class ApplicationScenarioTest(GraphScenarioTestBase):
             '--is-fallback-public-client True '
             '--service-management-reference {service_management_reference} '
             '--sign-in-audience AzureADMultipleOrgs '
+            # api
+            '--requested-access-token-version {requested_access_token_version} '
             # web
             '--web-home-page-url {homepage} '
             '--web-redirect-uris {web_redirect_uri_1} {web_redirect_uri_2} '
@@ -249,6 +252,7 @@ class ApplicationScenarioTest(GraphScenarioTestBase):
                 self.check('isFallbackPublicClient', True),
                 self.check('serviceManagementReference', '{service_management_reference}'),
                 self.check('signInAudience', 'AzureADMultipleOrgs'),
+                self.check('api.requestedAccessTokenVersion', '{requested_access_token_version}'),
                 self.check('web.homePageUrl', '{homepage}'),
                 self.check('web.redirectUris[0]', '{web_redirect_uri_1}'),
                 self.check('web.redirectUris[1]', '{web_redirect_uri_2}'),
@@ -287,6 +291,8 @@ class ApplicationScenarioTest(GraphScenarioTestBase):
             '--service-management-reference {service_management_reference} '
             # signInAudience can't be PATCHed currently due to service issue. PATCH first fails with 404, then 500
             # '--sign-in-audience AzureADMultipleOrgs '
+            # api
+            '--requested-access-token-version {requested_access_token_version} '
             # web
             '--web-home-page-url {homepage} '
             '--web-redirect-uris {web_redirect_uri_1} {web_redirect_uri_2} '
@@ -307,6 +313,9 @@ class ApplicationScenarioTest(GraphScenarioTestBase):
                 self.check('isFallbackPublicClient', True),
                 self.check('serviceManagementReference', '{service_management_reference}'),
                 # self.check('signInAudience', 'AzureADMultipleOrgs'),
+                # api
+                self.check('api.requestedAccessTokenVersion', '{requested_access_token_version}'),
+                # web
                 self.check('web.homePageUrl', '{homepage}'),
                 # redirectUris doesn't preserve item order.
                 # self.check('web.redirectUris[0]', '{web_redirect_uri_1}'),
@@ -333,7 +342,8 @@ class ApplicationScenarioTest(GraphScenarioTestBase):
     def test_app_create_idempotent(self):
         self.kwargs = {
             'display_name': self.create_random_name('azure-cli-test', 30),
-            'service_management_reference': '96524024-75b0-497b-ab38-0381399a6a9d'
+            'service_management_reference': '96524024-75b0-497b-ab38-0381399a6a9d',
+            'requested_access_token_version': 2
         }
 
         # These properties' values are null by default
@@ -341,18 +351,24 @@ class ApplicationScenarioTest(GraphScenarioTestBase):
             'ad app create --display-name {display_name} ',
             checks=[
                 self.check('isFallbackPublicClient', None),
-                self.check('serviceManagementReference', None)
+                self.check('serviceManagementReference', None),
+                # api
+                self.check('api.requestedAccessTokenVersion', None),
             ]).get_output_in_json()
         self.kwargs['app_id'] = result['appId']
 
         self.cmd(
             'ad app create --display-name {display_name} '
             '--is-fallback-public-client true '
-            '--service-management-reference {service_management_reference}',
+            '--service-management-reference {service_management_reference} '
+            # api
+            '--requested-access-token-version {requested_access_token_version}',
             checks=[
                 self.check('appId', '{app_id}'),
                 self.check('isFallbackPublicClient', True),
                 self.check('serviceManagementReference', '{service_management_reference}'),
+                # api
+                self.check('api.requestedAccessTokenVersion', '{requested_access_token_version}'),
             ])
 
     def test_app_resolution(self):
@@ -1020,5 +1036,5 @@ class GraphLiveScenarioTest(LiveScenarioTest):
 
 def _get_id_from_value(permissions, value):
     """Get id from value for appRoles or oauth2PermissionScopes."""
-    # https://docs.microsoft.com/en-us/graph/api/resources/serviceprincipal?view=graph-rest-1.0#properties
+    # https://learn.microsoft.com/en-us/graph/api/resources/serviceprincipal?view=graph-rest-1.0#properties
     return next(p['id'] for p in permissions if p['value'] == value)
