@@ -31,7 +31,7 @@ class StorageLegalHold(ScenarioTest):
 
     @AllowLargeResponse()
     @ResourceGroupPreparer()
-    @StorageAccountPreparer(kind='StorageV2', name_prefix='clitest', location='eastus2euap')
+    @StorageAccountPreparer(kind='StorageV2', name_prefix='clitest', location='eastus2')
     def test_legal_hold_with_allow_protected_append_writes_all(self, resource_group, storage_account):
         container_name = 'container1'
         self.cmd('storage container create --account-name {} -n {} --metadata k1=v1 k2=v2'.format(storage_account,
